# Generated by Django 5.2.3 on 2026-02-16 18:19

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "marinerg_test_access",
            "0009_accessapplicationboardreview_supporting_document_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="accessapplicationboardreview",
            name="application",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="board_reviews",
                to="marinerg_test_access.accessapplication",
            ),
        ),
    ]
