# Generated by Django 5.2.3 on 2026-02-02 12:12

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("marinerg_test_access", "0007_alter_facilitytestreport_datasets"),
    ]

    operations = [
        migrations.AddField(
            model_name="accesscall",
            name="active",
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name="accesscall",
            name="deleted_at",
            field=models.DateTimeField(default=django.utils.timezone.now, null=True),
        ),
        migrations.AddField(
            model_name="accesscall",
            name="public",
            field=models.BooleanField(default=True),
        ),
    ]
