# Generated by Django 5.2.3 on 2025-11-19 15:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "marinerg_test_access",
            "0002_accessapplicationboardreview_application_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="accessapplicationboarddecision",
            old_name="creator",
            new_name="reviewer",
        ),
        migrations.RenameField(
            model_name="accessapplicationboardreview",
            old_name="creator",
            new_name="reviewer",
        ),
        migrations.RemoveField(
            model_name="accessapplicationboardreview",
            name="call",
        ),
    ]
