# Generated by Django 5.2.3 on 2025-11-19 17:06

import django.db.models.deletion
import functools
import ichec_django_core.models.utils
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("marinerg_facility", "0007_equipmenttag_facilitytag_equipment_tags_and_more"),
        ("marinerg_test_access", "0004_remove_accessapplicationboarddecision_call"),
    ]

    operations = [
        migrations.AddField(
            model_name="facilitytestreport",
            name="facility",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="marinerg_facility.facility",
            ),
        ),
        migrations.AlterField(
            model_name="facilitytestreport",
            name="dataset_uri",
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name="facilitytestreport",
            name="report",
            field=models.FileField(
                null=True,
                upload_to=functools.partial(
                    ichec_django_core.models.utils.content_file_name, *("report",), **{}
                ),
            ),
        ),
    ]
