<html>
  <body>
    <h1>MARINERG-i Access Portal</h1>
    <p>There is a new access application for '{{facility_name}}' awaiting review as part of the '{{call}}' access call.</p>

    <p>You can view the application and complete the review via the <a href="{{domain}}/facility_reviews/{{id}}">access portal</a>.</p>

    <p>Thank you,</p>

    <p>The MARINERG-i Consortium</p>
  </body>
</html>
