# Generated by Django 5.2.3 on 2025-12-03 14:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("marinerg_data_access", "0004_datasettag_dataset_tags"),
        ("marinerg_test_access", "0006_remove_facilitytestreport_dataset_uri_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="facilitytestreport",
            name="datasets",
            field=models.ManyToManyField(
                blank=True,
                related_name="test_reports",
                to="marinerg_data_access.dataset",
                verbose_name="Datasets",
            ),
        ),
    ]
