# Generated by Django 5.2.3 on 2025-11-19 17:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("marinerg_facility", "0007_equipmenttag_facilitytag_equipment_tags_and_more"),
        ("marinerg_test_access", "0005_facilitytestreport_facility_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="facilitytestreport",
            name="dataset_uri",
        ),
        migrations.AddField(
            model_name="facilitytestreport",
            name="datasets",
            field=models.ManyToManyField(
                blank=True,
                related_name="test_reports",
                to="marinerg_facility.facility",
                verbose_name="Datasets",
            ),
        ),
    ]
