<html>
  <link rel="stylesheet" href="style.css">
  <body>
    <div class="logo_container" style="display: flex; justify-content: flex-end">
      <img class="logo" src="file://{{logo_path}}"/>
    </div>
    
    <header style="display: flex; justify-content: center">
      <h1 style="color: #003964">Access Application</h1>
    </header>

    <p>Submitted: {{submission_date}} </p>
    
    <h2>Applicant</h2>
    <p>Name: {{first_name}} {{last_name}}</p>
    <p>Email: {{email}}</p>
    
    <h2>Access Call</h2>
    <p>Title: {{call_title}}</p>
    <p>Coordinator: {{call_coordinator_email}}</p>
    <p>Closing Date: {{call_closing_date}}</p>
    
    {% if requested_facilities %}
    <h2>Preferred Facilities</h2>
    {% for facility in requested_facilities %}
    <p> {{ facility }} </p>
    {% endfor %}
    {% endif %}

    {% if chosen_facility %}
    <h2>Chosen Facility</h2>
    <p> {{ chosen_facility }} </p>
    {% endif %}    

    <h2>Dates</h2>
    {% if start_date %}
    <p>Requested Start Date: {{start_date}}</p>
    {% endif %}

    {% if end_date %}
    <p>Requested End Date: {{end_date}}</p>
    {% endif %}
    
    <p>Flexible: {{dates_flexible}}</p>

    <hr/>

    {% for field in fields %}
    <h3>{{field.label}}</h3>
    <p>{{field.value}}</p>
    {% endfor %}
  </body>
</html>

