# Generated by Django 5.2.3 on 2025-11-19 15:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "marinerg_test_access",
            "0003_rename_creator_accessapplicationboarddecision_reviewer_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="accessapplicationboarddecision",
            name="call",
        ),
    ]
