# Generated by Django 5.2.3 on 2026-02-05 19:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "marinerg_test_access",
            "0008_accesscall_active_accesscall_deleted_at_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="accessapplicationboardreview",
            name="supporting_document",
            field=models.FileField(null=True, upload_to=""),
        ),
        migrations.AddField(
            model_name="accesscall",
            name="contact_email",
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name="accesscall",
            name="review_template",
            field=models.FileField(null=True, upload_to=""),
        ),
        migrations.AddField(
            model_name="accesscall",
            name="use_facility_review",
            field=models.BooleanField(default=False),
        ),
    ]
